@@ -29,12 +29,8 @@ from __future__ import absolute_import
 
 import uuid
 
-import gevent
-from gevent import Greenlet
-from gevent.pool import Pool
-
 from slimta import logging
-from . import QueueStorage 
+from . import QueueStorage
 
 __all__ = ['DictStorage']
 
@@ -60,7 +56,7 @@ class DictStorage(QueueStorage):
     def write(self, envelope, timestamp):
         while True:
             id = uuid.uuid4().hex
-            if not self.env_db.has_key(id):
+            if id not in self.env_db:
                 self.env_db[id] = envelope
                 self.meta_db[id] = {'timestamp': timestamp, 'attempts': 0}
                 log.write(id, envelope)
@@ -80,6 +76,10 @@ class DictStorage(QueueStorage):
         log.update_meta(id, attempts=new_attempts)
         return new_attempts
 
+    def set_recipients_delivered(self, id, rcpt_indexes):
+        self._remove_delivered_rcpts(self.env_db[id], rcpt_indexes)
+        log.update_meta(id, delivered_indexes=rcpt_indexes)
+
     def load(self):
         for key in self.meta_db.keys():
             meta = self.meta_db[key]
@@ -100,5 +100,9 @@ class DictStorage(QueueStorage):
             pass
         log.remove(id)
 
+    def get_info(self):
+        return {'size': len(self.env_db),
+                'meta_size': len(self.meta_db)}
+
 
 # vim:et:fdm=marker:sts=4:sw=4:ts=4
